@font-face {
    font-family: "Open Sans";
    src: url("../assets/fonts/OpenSans-Regular.ttf") format("truetype");
    font-weight: normal;
    font-style: normal;
}
@font-face {
    font-family: "Open Sans";
    src: url("../assets/fonts/OpenSans-SemiBold.ttf") format("truetype");
    font-weight: bold;
    font-style: normal;
}
@font-face {
    font-family: "Open Sans";
    src: url("../assets/fonts/OpenSans-Light.ttf") format("truetype");
    font-weight: 100;
    font-style: normal;
}
.button {
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    box-sizing: content-box;
    color: #ffffff;
    cursor: pointer;
    display: inline-block;
    height: 1.5rem;
    line-height: 0.75rem;
    min-width: 1.5rem;
    outline: none;
    overflow: hidden;
    padding: 0;
    text-align: center;
    transition: background-color 250ms;
    -moz-user-select: none;
    user-select: none;
}
.button:hover {
    background-color: #193945;
    transition: background-color 125ms;
}
.button:active {
    background-color: #316e7d;
}
.button__wrapper {
    height: 100%;
    width: 100%;
}
.check-button .checkbox {
    width: calc(100% - 2 * 0.125rem);
}
.check-button .checkbox__checkmark {
    background-color: #316e7d;
}
.check-button .checkbox__checkmark::before,
.check-button .checkbox__checkmark::after {
    display: none;
}
.check-button .checkbox__content {
    align-items: center;
    display: flex;
    flex: auto;
    height: 1.5rem;
    justify-content: center;
    -moz-user-select: none;
    user-select: none;
}
.check-button .checkbox__input:checked ~ * {
    color: #ffffff;
}
.check-button .checkbox__input:checked ~ .checkbox__checkmark {
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M0,4 l2,2 l5,-5 v1.5 l-5,5 l-2,-2 z"/></svg>');
    background-position: center;
    background-repeat: no-repeat;
    background-size: 1rem;
}
.check-button__description {
    display: inline-block;
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
    -moz-user-select: none;
    user-select: none;
    width: 100%;
}
.checkbox {
    align-items: stretch;
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    cursor: pointer;
    display: inline-flex;
    flex: none;
    flex-direction: row;
    height: 1.5rem;
    transition: background-color 250ms;
    width: 1.5rem;
}
.checkbox:hover {
    background-color: #193945;
    transition: background-color 125ms;
}
.checkbox__input {
    display: none;
}
.checkbox__checkmark {
    display: inline-block;
    height: 100%;
    position: relative;
    width: 1.5rem;
}
.checkbox__checkmark::before,
.checkbox__checkmark::after {
    background-color: #316e7d;
    content: "";
    display: inline-block;
    height: 0.1875rem;
    left: 0.1875rem;
    position: absolute;
    top: 0.6375rem;
    transition: all 125ms;
    width: 1.125rem;
}
.checkbox__checkmark::before {
    transform: skewY(45deg);
}
.checkbox__checkmark::after {
    transform: skewY(-45deg);
}
.checkbox__input:checked + .checkbox__checkmark::before,
.checkbox__input:checked + .checkbox__checkmark::after {
    background-color: #ffffff;
}
.checkbox__input:checked + .checkbox__checkmark::before {
    top: 0.825rem;
    width: 0.375rem;
}
.checkbox__input:checked + .checkbox__checkmark::after {
    left: 0.5625rem;
    width: 0.75rem;
}
.control-group {
    align-items: stretch;
    display: inline-flex;
    flex-direction: column;
    width: 100%;
}
.control-group__control {
    height: 1.75rem;
}
.control-group__description {
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
    -moz-user-select: none;
    user-select: none;
}
.dropdown {
    display: inline-block;
    height: 1.5rem;
    position: relative;
    -moz-user-select: none;
    user-select: none;
    width: 100%;
}
.dropdown__selected {
    align-items: center;
    background-color: #316e7d;
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M1,2 l3,3 l3,-3 v1.5 l-3,3 l-3,-3 z"/></svg>');
    background-position: center right 0.25rem;
    background-repeat: no-repeat;
    background-size: 1rem;
    color: #ffffff;
    display: inline-flex;
    height: 1.25rem;
    justify-content: center;
    line-height: 1.25rem;
    margin-top: 0.125rem;
    position: absolute;
    text-align: center;
    width: 100%;
}
.dropdown__selected__text {
    display: inline-block;
    max-width: calc(100% - 2.5rem);
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}
.dropdown__list {
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    border-top: none;
    box-shadow: 0 0 0.25rem black;
    box-sizing: border-box;
    display: none;
    margin-top: 0.125rem;
    overflow: hidden;
    position: absolute;
    width: 100%;
}
.dropdown__list__item {
    align-items: center;
    background-color: #141e24;
    color: #ffffff;
    display: inline-flex;
    justify-content: center;
    min-height: 1.25rem;
    text-align: center;
    width: 100%;
}
.dropdown__list__item:hover {
    background-color: #193945;
    transition: background-color 125ms;
}
.dropdown__list__item--selected {
    overflow: hidden;
    visibility: hidden;
    white-space: nowrap;
}
.dropdown--open .dropdown__list {
    display: inline-block;
    margin-top: 0rem;
    z-index: 1;
}
.dropdown--open .dropdown__list__item {
    min-height: 1.5rem;
}
.dropdown--open .dropdown__selected {
    height: 1.5rem;
    margin-top: 0rem;
    z-index: 2;
}
.preview .dropdown {
    cursor: pointer;
}
.message-box {
    background-color: #141e24;
    border-bottom: 0.125rem solid #316e7d;
    border-top: 0.125rem solid #316e7d;
    display: flex;
    flex-direction: column;
    padding: 0.75rem;
}
.message-box__caption {
    text-align: center;
}
.message-box__buttons {
    display: flex;
    flex-direction: row;
    justify-content: center;
    margin-top: 0.5rem;
}
.message-box__button {
    min-width: 4rem;
}
.message-box__button:not(:first-child) {
    margin-left: 0.5rem;
}
.message-box__button-ok {
    border-color: gray;
}
.multi-switch {
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    box-sizing: content-box;
    color: #ffffff;
    display: inline-flex;
    height: 1.5rem;
    position: relative;
    -moz-user-select: none;
    user-select: none;
}
.multi-switch__option {
    align-items: center;
    cursor: pointer;
    display: inline-flex;
    justify-content: center;
    height: 100%;
    overflow: hidden;
    position: relative;
    transition: background-color 250ms;
    white-space: nowrap;
    width: 50%;
}
.multi-switch__option:hover:not(.multi-switch__option--selected) {
    background-color: #193945;
}
.multi-switch__highlight {
    background-color: #316e7d;
    display: inline-block;
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    transition:
        left 125ms,
        width 125ms;
    width: 0;
}
.overlay {
    align-items: center;
    background-color: rgba(20, 30, 36, 0.5);
    flex-direction: column;
    display: inline-flex;
    height: 100%;
    justify-content: center;
    left: 0;
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 2;
}
.overlay:empty {
    display: none;
}
.shortcut {
    color: #53a1b3;
    cursor: pointer;
    display: inline-block;
    font-size: 0.625rem;
    line-height: 0.875rem;
    outline: none;
    text-align: center;
    text-decoration: none;
    white-space: pre;
}
.shortcut:hover {
    text-decoration: underline;
}
.shortcut--edit {
    color: #ffffff;
}
.shortcut::before {
    content: "✎";
    direction: rtl;
    display: inline-block;
    line-height: 0.875rem;
    visibility: hidden;
    width: 0;
}
.shortcut:hover::before,
.shortcut--edit::before {
    visibility: visible;
}
.tab-panel {
    align-items: stretch;
    display: flex;
    flex-direction: column;
    min-height: 0;
}
.tab-panel__button {
    border-bottom: 0.125rem solid #316e7d;
    border-left: none;
    border-right: none;
    border-top: none;
    box-sizing: border-box;
    color: #316e7d;
    font-size: 0.875rem;
    font-weight: bold;
    height: 1.625rem;
    padding: 0 0.625rem;
    white-space: pre;
}
.tab-panel__button:hover {
    color: #53a1b3;
}
.tab-panel__button:active {
    background-color: #193945;
}
.tab-panel__button--active {
    border-bottom: none;
    border-left: 0.125rem solid #316e7d;
    border-right: 0.125rem solid #316e7d;
    border-top: 0.125rem solid #316e7d;
    color: #e96c4c;
    padding: 0 0.5rem;
}
.tab-panel__button--active:hover {
    color: #e96c4c;
}
.tab-panel__buttons {
    display: flex;
    flex: none;
    flex-direction: row;
    justify-content: center;
}
.tab-panel__buttons::before,
.tab-panel__buttons::after {
    border-bottom: 0.125rem solid #316e7d;
    content: "";
    flex: auto;
}
.tab-panel__tabs {
    display: flex;
    flex: auto;
    flex-direction: row;
    margin-top: 0.75rem;
    min-height: 0;
}
.tab-panel__tab {
    background-color: #141e24;
    display: flex;
    opacity: 0;
    overflow: hidden;
    pointer-events: none;
    transition:
        width 250ms,
        opacity 125ms;
    width: 0;
}
.tab-panel__tab--active {
    opacity: 1;
    pointer-events: all;
    transition:
        width 250ms,
        opacity 250ms;
    width: 100%;
}
.select {
    display: inline-flex;
    flex-direction: column;
    position: relative;
}
.select__line {
    display: inline-flex;
    flex-direction: row;
}
.select__textbox.textbox {
    border-right: none;
    flex: auto;
    width: 100%;
}
.select__expand {
    border-left: none;
    flex: none;
}
.select__expand__icon {
    display: inline-block;
    height: 100%;
    position: relative;
    width: 100%;
}
.select__expand__icon::before,
.select__expand__icon::after {
    background-color: #ffffff;
    content: "";
    display: inline-block;
    height: 0.1875rem;
    position: absolute;
    top: 0.75rem;
    width: 0.5625rem;
    z-index: 1;
}
.select__expand__icon::before {
    left: 0.1875rem;
    transform: skewY(45deg);
}
.select__expand__icon::after {
    left: 0.75rem;
    transform: skewY(-45deg);
}
.select__list {
    background-color: #141e24;
    border-bottom: 0.125rem solid #316e7d;
    border-left: 0.125rem solid #316e7d;
    border-right: 0.125rem solid #316e7d;
    box-sizing: border-box;
    left: 0;
    max-height: 0;
    overflow-x: hidden;
    overflow-y: auto;
    position: absolute;
    top: calc(100% - 0.125rem);
    transition: max-height 125ms;
    width: 100%;
    z-index: 999;
}
.select__list--expanded {
    max-height: 12rem;
    transition: max-height 500ms;
}
.select__list--short {
    overflow: hidden;
}
.select__option {
    align-items: center;
    background-color: #141e24;
    cursor: pointer;
    display: flex;
    flex: none;
    height: 1.5rem;
    flex-direction: row;
    padding-left: 0.375rem;
}
.select__option:hover {
    background-color: #193945;
}
.slider {
    display: inline-block;
    height: 1.5rem;
    position: relative;
    touch-action: none;
    width: 100%;
}
.slider__track {
    background-color: #193945;
    display: inline-block;
    height: 0.625rem;
    margin-left: 0.25rem;
    margin-top: 0.4375rem;
    position: absolute;
    width: calc(100% - 0.5rem);
}
.slider__track__fill {
    background-color: #316e7d;
    display: inline-block;
    height: 100%;
    position: absolute;
}
.slider__track__fill::before {
    background-color: #316e7d;
    content: "";
    height: 100%;
    position: absolute;
    right: 100%;
    width: 0.25rem;
}
.slider__track::before,
.slider__track::after {
    background-color: #193945;
    content: "";
    height: 100%;
    position: absolute;
    width: 0.25rem;
}
.slider__track::before {
    right: 100%;
}
.slider__track::after {
    left: 100%;
}
.slider__thumb-wrapper {
    margin-left: 0.25rem;
    position: absolute;
    width: calc(100% - 0.5rem);
}
.slider__thumb {
    background-color: #ffffff;
    cursor: pointer;
    display: inline-block;
    height: 1.25rem;
    margin-left: -0.25rem;
    margin-top: 0.125rem;
    position: absolute;
    width: 0.5rem;
}
.slider__thumb__value {
    color: #ffffff;
    cursor: default;
    left: calc(100% + 0.75rem / 2);
    line-height: 1.25rem;
    position: absolute;
    -moz-user-select: none;
    user-select: none;
}
.slider__thumb__value--flip {
    left: initial;
    right: calc(100% + 0.75rem / 2);
}
.slider--active .slider__thumb {
    box-shadow: 0 0 0.25rem black;
    height: 1.5rem;
    margin-top: 0rem;
}
.slider--active .slider__thumb__value {
    line-height: 1.5rem;
}
.slider--active .slider__track {
    height: 0.75rem;
    margin-top: 0.375rem;
}
.slider__value {
    display: none;
}
.text-list {
    border-top: 0.125rem solid #316e7d;
    margin-bottom: 0.0625rem;
    min-width: 1.5rem;
    overflow-x: hidden;
    overflow-y: auto;
}
.text-list__textbox.textbox {
    border-bottom: 0.0625rem solid #316e7d;
    border-left: 0.125rem solid #316e7d;
    border-right: 0.125rem solid #316e7d;
    border-top: none;
    box-sizing: border-box;
    flex: none;
    height: 1.5625rem;
    width: 100%;
}
.text-list__textbox.textbox:last-child {
    border-bottom: 0.125rem solid #316e7d;
}
.text-list::-webkit-scrollbar {
    width: 1.25rem;
}
.text-list::-webkit-scrollbar-thumb {
    border-left: 0.5rem solid #141e24;
}
.textbox {
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    box-sizing: content-box;
    color: #53a1b3;
    height: 1.5rem;
    line-height: 1.5rem;
    outline: none;
    overflow: hidden;
    padding: 0;
    text-indent: 0.375rem;
    transition: background-color 250ms;
}
.textbox:hover,
.textbox:focus {
    background-color: #193945;
    transition: background-color 125ms;
}
.textbox:focus {
    color: #ffffff;
}
.textbox::placeholder {
    color: #316e7d;
}
input[type="time"]::-webkit-calendar-picker-indicator {
    filter: invert(54%) sepia(3%) saturate(3931%) hue-rotate(153deg)
        brightness(115%) contrast(75%);
}
.time-range-picker {
    display: inline-flex;
    flex: auto;
}
.time-range-picker__input {
    text-align: center;
    text-indent: 0;
    width: 100%;
    background-color: #141e24;
}
.time-range-picker__input--start {
    border-right: none;
}
.time-range-picker__input--end {
    border-left: 0.0625rem solid #316e7d;
}
.toggle {
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    box-sizing: content-box;
    color: #ffffff;
    display: inline-flex;
    height: 1.5rem;
    position: relative;
    -moz-user-select: none;
    user-select: none;
}
.toggle__btn {
    align-items: center;
    cursor: pointer;
    display: inline-flex;
    justify-content: center;
    height: 100%;
    overflow: hidden;
    position: relative;
    transition: background-color 250ms;
    white-space: nowrap;
    width: 50%;
}
.toggle__btn:hover:not(.toggle__btn--active) {
    background-color: #193945;
}
.toggle::before {
    background-color: #316e7d;
    content: "";
    display: inline-block;
    height: 100%;
    left: 50%;
    position: absolute;
    top: 0;
    transition: left 125ms;
    width: 50%;
}
.toggle--checked::before {
    left: 0;
}
.updown {
    align-items: stretch;
    display: flex;
    flex-direction: column;
    -moz-user-select: none;
    user-select: none;
}
.updown__line {
    display: flex;
    flex-direction: row;
}
.updown__line > :not(:first-child) {
    margin-left: 0.5rem;
}
.updown__icon {
    display: inline-block;
    height: 100%;
    position: relative;
    width: 100%;
}
.updown__icon::before,
.updown__icon::after {
    background-color: #ffffff;
    content: "";
    display: inline-block;
    height: 0.5625rem;
    position: absolute;
    width: 0.1875rem;
}
.updown__icon::before {
    top: 0.1875rem;
}
.updown__icon::after {
    top: 0.75rem;
}
.updown__icon-up::before {
    left: 0.75rem;
    transform: skewX(45deg);
}
.updown__icon-up::after {
    left: 0.75rem;
    transform: skewX(-45deg);
}
.updown__icon-down::before {
    left: 0.5625rem;
    transform: skewX(-45deg);
}
.updown__icon-down::after {
    left: 0.5625rem;
    transform: skewX(45deg);
}
.updown__button--disabled {
    pointer-events: none;
}
.updown__button--disabled:hover,
.updown__button--disabled:active {
    background-color: #141e24;
}
.updown__button--disabled .updown__icon::before,
.updown__button--disabled .updown__icon::after {
    background-color: #316e7d;
}
.updown__value-text {
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
    white-space: nowrap;
}
.track {
    align-items: center;
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    box-sizing: content-box;
    display: inline-flex;
    flex: auto;
    flex-direction: row;
    height: 1.5rem;
    justify-content: center;
    overflow: hidden;
    position: relative;
    transition: background-color 250ms;
    -moz-user-select: none;
    user-select: none;
}
.track:hover {
    background-color: #193945;
    transition: background-color 125ms;
}
.track--clickable {
    cursor: pointer;
}
.track__value {
    background-color: #316e7d;
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    transition: width 125ms;
}
.track__label {
    color: #ffffff;
    display: inline-block;
    line-height: 0.75rem;
    pointer-events: none;
    position: relative;
    white-space: nowrap;
    z-index: 1;
}
.hsb-picker {
    display: flex;
    flex-direction: row;
    padding: 0.5rem;
    touch-action: none;
}
.hsb-picker__sb-container {
    cursor: pointer;
    height: 7.5rem;
    position: relative;
    -webkit-tap-highlight-color: transparent;
    width: 7.5rem;
}
.hsb-picker__hue-container {
    cursor: pointer;
    height: 7.5rem;
    margin-left: 0.5rem;
    position: relative;
    -webkit-tap-highlight-color: transparent;
    width: 0.75rem;
}
.hsb-picker__sb-canvas {
    height: 100%;
    width: 100%;
}
.hsb-picker__hue-canvas {
    height: 100%;
    width: 100%;
}
.hsb-picker__hue-cursor,
.hsb-picker__sb-cursor {
    border-radius: 50%;
    box-shadow: 0 0 0 0.125rem #ffffff;
    display: inline-block;
    height: 0.75rem;
    margin-top: -0.375rem;
    position: absolute;
    width: 0.75rem;
    z-index: 2;
}
.hsb-picker__sb-cursor {
    margin-left: -0.375rem;
}
.color-picker {
    height: 1.5rem;
    position: relative;
    width: 100%;
}
.color-picker__wrapper {
    background-color: #141e24;
    display: inline-flex;
    flex-direction: column;
    left: 0;
    overflow: hidden;
    position: absolute;
    top: 0;
    width: 100%;
}
.color-picker--focused .color-picker__wrapper {
    border: 0.125rem solid #316e7d;
    box-sizing: border-box;
    z-index: 1;
}
.color-picker__input {
    background-color: #316e7d;
    border: none;
    box-sizing: border-box;
    color: #ffffff;
    height: 1.25rem;
    margin-top: 0.125rem;
    text-align: center;
    width: 100%;
}
.color-picker--focused .color-picker__input {
    margin-top: 0;
}
.color-picker__preview {
    cursor: pointer;
    display: inline-block;
    height: 1rem;
    left: 0.25rem;
    position: absolute;
    top: 0.25rem;
    width: 1rem;
}
.color-picker--focused .color-picker__preview {
    left: 0.125rem;
    top: 0.125rem;
}
.color-picker__reset {
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M4,1 v-1 l1.5,1.5 l-1.5,1.5 v-1 a2,2 0 1 0 2,2 h1 a3,3 0 1 1 -3,-3 z"/></svg>');
    background-position: 0 0;
    background-repeat: no-repeat;
    background-size: 1rem;
    cursor: pointer;
    display: inline-block;
    height: 1rem;
    position: absolute;
    right: 0.25rem;
    top: 0.25rem;
    width: 1rem;
}
.color-picker--focused .color-picker__reset {
    right: 0.125rem;
    top: 0.125rem;
}
.color-picker__textbox-line {
    width: 100%;
}
.color-picker__hsb-line {
    display: none;
    width: 100%;
}
.color-picker--focused .color-picker__hsb-line {
    border-color: #316e7d;
    display: block;
}
.color-dropdown {
    height: 1.5rem;
    position: relative;
    width: 100%;
}
.color-dropdown__options {
    width: 100%;
}
.color-dropdown__picker {
    height: 100%;
    position: absolute;
    right: 0;
    top: 0;
    width: 100%;
}
.color-dropdown__picker--hidden {
    display: none;
}
.nav-button {
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M2,1 h1.5 l3,3 l-3,3 h-1.5 l3,-3 z"/></svg>');
    background-position: center right 0.25rem;
    background-repeat: no-repeat;
    background-size: 1rem;
    width: calc(100% - 2 * 0.125rem);
}
.nav-button__content {
    align-items: center;
    display: inline-flex;
    flex-direction: row;
    height: 100%;
}
.reset-button {
    width: calc(100% - 2 * 0.125rem);
}
.reset-button__content {
    align-items: center;
    display: inline-flex;
    flex-direction: row;
    height: 100%;
}
.reset-button__icon {
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M4,1 v-1 l1.5,1.5 l-1.5,1.5 v-1 a2,2 0 1 0 2,2 h1 a3,3 0 1 1 -3,-3 z"/></svg>');
    background-position: 0 0;
    background-size: 1rem;
    display: inline-block;
    height: 1rem;
    margin-right: 0.125rem;
    width: 1rem;
}
html {
    background-color: #141e24;
    color: #53a1b3;
    color-scheme: dark;
    font-family:
        Open Sans,
        Segoe UI,
        Helvetica Neue,
        Ubuntu,
        sans-serif;
    font-size: 16px;
}
body {
    font-family:
        Open Sans,
        Segoe UI,
        Helvetica Neue,
        Ubuntu,
        sans-serif;
    font-size: 0.75rem;
}
input,
button {
    font-family:
        Open Sans,
        Segoe UI,
        Helvetica Neue,
        Ubuntu,
        sans-serif;
    font-size: 0.75rem;
}
::-moz-selection {
    background-color: #e96c4c;
    color: #ffffff;
}
::selection {
    background-color: #e96c4c;
    color: #ffffff;
}
::-webkit-scrollbar {
    background-color: #141e24;
    width: 0.75rem;
}
::-webkit-scrollbar-thumb {
    background-color: #193945;
}
::-webkit-scrollbar-thumb:hover {
    background-color: #255461;
}
::-webkit-scrollbar-thumb:active {
    background-color: #316e7d;
}
::-webkit-scrollbar-corner {
    background-color: #141e24;
}
* {
    scrollbar-color: #193945 #141e24;
}
.custom-settings-toggle {
    color: #53a1b3;
    white-space: normal;
}
.custom-settings-toggle--checked,
.custom-settings-toggle:active,
.custom-settings-toggle--checked:hover {
    background-color: #316e7d;
    color: #75b4c2;
    transition:
        background-color 125ms,
        color 125ms;
}
.custom-settings-toggle--disabled {
    opacity: 0.5;
    pointer-events: none;
}
.custom-settings-toggle__url {
    color: #ffffff;
    -moz-user-select: none;
    user-select: none;
}
.custom-settings-toggle .button__wrapper {
    align-items: center;
    display: inline-flex;
    justify-content: center;
    min-width: 14.75rem;
}
.engine-switch {
    align-items: stretch;
    display: flex;
    flex-direction: column;
    position: relative;
}
.engine-switch__description {
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
    white-space: nowrap;
}
.engine-switch__css-edit-button {
    background-color: #e96c4c;
    border-radius: 0.4375rem;
    color: #ffffff;
    cursor: pointer;
    display: none;
    font-size: 0.625rem;
    line-height: 0.875rem;
    min-width: 0.875rem;
    position: absolute;
    right: 0;
    text-align: center;
    top: -0.21875rem;
}
.engine-switch__css-edit-button_active {
    display: inline-block;
}
.engine-switch__css-edit-button::before {
    content: "✎";
    line-height: 0.875rem;
}
.engine-switch__css-edit-button:hover {
    box-shadow: 0 0 0.75rem #ffffff;
}
.filter-settings {
    align-items: stretch;
    display: flex;
    flex-direction: column;
    width: 100%;
}
.filter-settings > :not(:first-child) {
    margin-top: 0.5rem;
}
.filter-settings__content {
    align-items: center;
    display: flex;
    flex: auto;
    flex-direction: column;
    justify-content: center;
}
.mode-toggle {
    align-items: stretch;
    display: flex;
    flex-direction: column;
    -moz-user-select: none;
    user-select: none;
}
.mode-toggle__line {
    display: flex;
    flex-direction: row;
}
.mode-toggle__line > :not(:first-child) {
    margin-left: 0.5rem;
}
.mode-toggle .toggle {
    flex: auto;
}
.mode-toggle__label {
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
}
.mode-toggle__button--active {
    background: #316e7d;
}
.mode-toggle__button--active:hover {
    background: #316e7d;
}
.icon {
    background-size: contain;
    display: inline-block;
    height: 100%;
    width: 100%;
}
.icon--dark-mode {
    background-image: url(../assets/images/mode-dark-32.svg);
}
.icon--light-mode {
    background-image: url(../assets/images/mode-light-32.svg);
}
.font-settings {
    display: flex;
    flex-direction: column;
    width: 100%;
}
.font-settings__font-select-container {
    display: flex;
    flex-direction: column;
}
.font-settings__font-select-container__line {
    display: flex;
    flex-direction: row;
}
.font-settings__font-select-container__line > :not(:first-child) {
    margin-left: 0.5rem;
}
.font-settings__font-select-container__line .select {
    flex: auto;
}
.font-settings__font-select-container__label {
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
    white-space: nowrap;
}
.font-settings > :not(:first-child) {
    margin-top: 0.5rem;
}
.header {
    display: grid;
    grid: "logo logo" "site-toggle app-toggle" / 5.5fr 4.5fr;
    grid-gap: 0.5rem;
    width: 100%;
}
.header__logo {
    background-image: url("../assets/images/darkreader-type.svg");
    background-size: 100%;
    grid-area: logo;
    height: 1.5rem;
    outline: none;
    text-indent: -999rem;
    width: 15rem;
}
.header__logo:hover {
    filter: brightness(1.05);
}
.header__control {
    display: flex;
    flex-direction: column;
}
.header__site-toggle {
    grid-area: site-toggle;
    min-width: 0;
}
.header__app-toggle {
    grid-area: app-toggle;
    min-width: 0;
    position: relative;
}
.header__app-toggle__time {
    background-color: #e96c4c;
    border-radius: 50%;
    color: #ffffff;
    cursor: pointer;
    display: none;
    height: 0.875rem;
    pointer-events: none;
    position: absolute;
    right: -0.21875rem;
    top: -0.21875rem;
    transition: opacity 250ms 250ms;
    width: 0.875rem;
}
.header__app-toggle__time--active {
    display: inline-block;
}
.header__more-settings-button {
    cursor: pointer;
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
    user-select: none;
}
.header__more-settings-button:hover {
    text-decoration: underline;
}
.header__more-settings-button__icon {
    height: 0.625rem;
    margin-right: 0.125rem;
    position: relative;
    top: 0.0625rem;
    width: 0.625rem;
}
.header__more-settings-button__icon g {
    fill: #53a1b3;
}
.header__more-settings-button--off {
    color: #e96c4c;
}
.header__more-settings-button--off .header__more-settings-button__icon g {
    fill: #e96c4c;
}
.header__more-site-settings {
    height: 14.5rem;
}
.header__more-toggle-settings {
    height: 18rem;
}
.header__more-settings {
    background-color: rgba(20, 30, 36, 0.9);
    border-bottom: 0.125rem solid #316e7d;
    border-top: 0.125rem solid #316e7d;
    display: flex;
    flex-direction: column;
    left: 0;
    position: absolute;
    top: 6.875rem;
    transition: all 250ms;
    width: 100%;
    z-index: 999;
}
.header__more-settings:not(.header__more-settings--expanded) {
    height: 0;
    opacity: 0;
    pointer-events: none;
}
.header__more-settings__top {
    align-items: center;
    color: #e96c4c;
    display: flex;
    flex: auto;
    font-size: 0.875rem;
    height: 1.5rem;
    justify-content: space-between;
    overflow: hidden;
    padding-left: 1rem;
}
.header__more-settings__top__text {
    line-height: 1rem;
}
.header__more-settings__top__close {
    color: #e96c4c;
    cursor: pointer;
    display: inline-block;
    font-size: 1.125rem;
    height: 1.5rem;
    line-height: 1.5rem;
    text-align: center;
    user-select: none;
    width: 1.5rem;
}
.header__more-settings__top__close:hover {
    background-color: rgba(49, 110, 125, 0.25);
}
.header__more-settings__content {
    flex: auto;
    overflow: hidden;
    padding: 0.75rem 1rem;
    transition: padding 250ms;
}
.header__more-settings__line {
    display: flex;
    flex-direction: row;
}
.header__more-settings__line .checkbox {
    border-right: none;
    flex: none;
}
.header__more-settings__line
    .time-range-picker
    .time-range-picker__input--start {
    border-left: 0.0625rem solid #316e7d;
}
.header__more-settings__description {
    font-size: 0.625rem;
    line-height: 0.875rem;
    margin: 0;
    text-align: center;
    white-space: nowrap;
}
.header__more-settings__warning {
    font-size: 0.625rem;
    line-height: 0.875rem;
    margin: 0;
    text-align: center;
    white-space: pre;
    color: #e96c4c;
}
.header__more-settings__location-description {
    font-size: 0.625rem;
    line-height: 0.875rem;
    margin: 0;
    text-align: center;
    white-space: nowrap;
}
.header__more-settings::after {
    background-image: linear-gradient(
        to bottom,
        rgba(20, 30, 36, 0.9),
        rgba(20, 30, 36, 0)
    );
    content: "";
    display: block;
    height: 1.5rem;
    left: 0;
    margin-top: 0.125rem;
    pointer-events: none;
    position: absolute;
    top: 100%;
    transition: height 250ms;
    width: 100%;
}
.header__more-settings__location {
    margin-top: 0.5rem;
}
.header__more-settings__location__latitude,
.header__more-settings__location__longitude {
    flex: auto;
    text-align: center;
    text-indent: 0;
    width: 100%;
}
.header__more-settings__location__latitude {
    border-left: 0.0625rem solid #316e7d;
    border-right: none;
}
.header__more-settings__location__longitude {
    border-left: 0.0625rem solid #316e7d;
}
.header__more-settings__system-dark-mode {
    display: flex;
    flex-direction: row;
    margin-top: 0.5rem;
}
.header__more-settings__system-dark-mode__checkbox {
    flex: none;
}
.header__more-settings__system-dark-mode__button {
    border-left-width: 0.0625rem;
    flex: auto;
}
.header__more-settings__system-dark-mode__button:not(
    .header__more-settings__system-dark-mode__button--active
) {
    color: #53a1b3;
}
.header__more-settings__system-dark-mode:hover
    .header__more-settings__system-dark-mode__button,
.header__more-settings__system-dark-mode:hover
    .header__more-settings__system-dark-mode__checkbox {
    background-color: #193945;
}
.header__more-settings__shortcut-wrapper {
    display: inline-block;
    height: 1.75rem;
    margin-top: 0.5rem;
    position: relative;
    width: 100%;
}
.header__more-settings__shortcut-wrapper svg {
    --icon-color: #316e7d;
    border-right: 0.0625rem solid #316e7d;
    height: 1.5rem;
    left: 0.125rem;
    pointer-events: none;
    position: absolute;
    top: 0.125rem;
    width: 1.5rem;
}
.header__more-settings__shortcut-wrapper--set svg {
    --icon-color: #ffffff;
}
.header__more-settings__shortcut {
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    font-size: 0.75rem;
    height: 1.5rem;
    line-height: 1.5rem;
    padding-left: 1.5rem;
    position: relative;
    transition: all 125ms;
    white-space: nowrap;
    width: calc(100% - 2 * 0.125rem - 1.5rem);
}
.header__more-settings__shortcut:hover {
    background-color: #193945;
    text-decoration: none;
}
.header__more-settings__shortcut:hover::before {
    display: none;
}
.header__more-settings__enabled-by-default {
    display: flex;
    flex-direction: row;
}
.header__more-settings__enabled-by-default__checkbox {
    flex: none;
}
.header__more-settings__enabled-by-default__button {
    border-left-width: 0.0625rem;
    flex: auto;
}
.header__more-settings__enabled-by-default__button:not(
    .header__more-settings__enabled-by-default__button--active
) {
    color: #53a1b3;
}
.header__more-settings__enabled-by-default:hover
    .header__more-settings__enabled-by-default__button,
.header__more-settings__enabled-by-default:hover
    .header__more-settings__enabled-by-default__checkbox {
    background-color: #193945;
}
.header__more-settings__detect-dark-theme {
    display: flex;
    flex-direction: row;
    margin-top: 0.5rem;
}
.header__more-settings__detect-dark-theme__checkbox {
    flex: none;
}
.header__more-settings__detect-dark-theme__button {
    border-left-width: 0.0625rem;
    flex: auto;
}
.header__more-settings__detect-dark-theme__button:not(
    .header__more-settings__detect-dark-theme__button--active
) {
    color: #53a1b3;
}
.header__more-settings__detect-dark-theme:hover
    .header__more-settings__detect-dark-theme__button,
.header__more-settings__detect-dark-theme:hover
    .header__more-settings__detect-dark-theme__checkbox {
    background-color: #193945;
}
.header__more-settings__donate {
    margin-top: 0.5rem;
}
.header__more-settings__donate .donate-link {
    width: 100%;
}
.header .shortcut {
    overflow: hidden;
}
.header__more-new-highlight {
    height: 2rem;
    pointer-events: none;
    position: absolute;
    right: 0rem;
    top: 5.75rem;
    width: 17rem;
}
.header__more-new-highlight__text {
    background: #e96c4c;
    bottom: 0;
    color: #ffffff;
    display: inline-block;
    line-height: 0.75rem;
    padding: 0.25rem;
    position: absolute;
    right: 0.5rem;
}
.header__more-new-highlight__lines path {
    fill: none;
    stroke: #e96c4c;
    stroke-linecap: round;
    stroke-linejoin: round;
    stroke-width: 2;
}
.header__more-new-highlight__lines circle {
    fill: #e96c4c;
    stroke: none;
}
.loader {
    background-color: #141e24;
    height: 32rem;
    left: 50%;
    pointer-events: none;
    position: fixed;
    top: 50%;
    transform: translate(-50%, -50%);
    transition: background-color 125ms ease-out;
    width: 17rem;
    z-index: 999;
}
.loader--complete {
    background-color: rgba(20, 30, 36, 0);
}
.loader--complete::before {
    opacity: 0;
    transition: opacity 125ms ease-in;
}
.loader--transition-end {
    display: none;
}
.loader::before {
    animation:
        2s loading-slide 500ms ease-in-out infinite,
        4s 500ms loading-color linear infinite;
    background-color: #316e7d;
    content: "";
    display: block;
    height: 0.0625rem;
    left: 0%;
    position: absolute;
    top: 3rem;
    width: 0%;
}
.loader__message {
    animation: 125ms loading-fade-in 500ms ease-in forwards;
    color: #e96c4c;
    font-size: 0.625rem;
    opacity: 0;
    position: absolute;
    right: 1rem;
    bottom: 29rem;
}
.loader__error {
    font-size: 0.75rem;
}
.loader--complete .loader__message {
    color: rgba(233, 108, 76, 0);
    transition: color 125ms ease-out;
}
@keyframes loading-slide {
    0% {
        left: 0%;
        width: 0%;
    }
    50% {
        left: 0%;
        width: 100%;
    }
    100% {
        left: 100%;
        width: 0%;
    }
}
@keyframes loading-color {
    0%,
    49% {
        background-color: #316e7d;
    }
    50%,
    100% {
        background-color: #e96c4c;
    }
}
@keyframes loading-fade-in {
    from {
        opacity: 0;
    }
    to {
        opacity: 1;
    }
}
.more-settings {
    display: flex;
    flex-direction: column;
    width: 100%;
}
.more-settings__description {
    font-size: 0.625rem;
    line-height: 0.875rem;
    margin: 0 0 0.125rem 0;
    min-width: 100%;
    overflow: hidden;
    text-align: center;
    white-space: pre;
}
.more-settings__description--warning {
    color: #e96c4c;
}
.more-settings__warning {
    color: #e96c4c;
    white-space: pre;
}
.more-settings__section {
    align-items: stretch;
    display: flex;
    flex-direction: column;
}
.more-settings__section:not(:first-child) {
    margin-top: 0.75rem;
}
.more-settings__settings-button__wrapper {
    align-items: center;
    display: inline-flex;
    flex-direction: row;
    flex-wrap: nowrap;
    gap: 0.25rem;
    justify-content: center;
}
.more-settings__settings-button__icon {
    display: inline-block;
    height: 1rem;
    width: 1rem;
}
.more-settings__settings-button__text {
    display: inline-block;
    white-space: nowrap;
}
.news {
    bottom: 2.625rem;
    box-sizing: border-box;
    display: flex;
    flex-direction: column;
    left: 0;
    max-height: 0;
    opacity: 0;
    overflow: hidden;
    pointer-events: none;
    position: absolute;
    text-align: left;
    transition: all 250ms;
    width: 100%;
    z-index: 1;
}
.news--expanded {
    max-height: 12rem;
    opacity: 1;
    pointer-events: initial;
}
.news::before {
    background-image: linear-gradient(to top, #141e24, rgba(20, 30, 36, 0));
    content: "";
    display: block;
    height: 1.5rem;
    pointer-events: none;
    width: 100%;
}
.news__header {
    align-items: flex-end;
    background-image: linear-gradient(
        to bottom,
        rgba(20, 30, 36, 0.9),
        rgba(20, 30, 36, 0.95)
    );
    border-top: 0.125rem solid #316e7d;
    color: #e96c4c;
    display: flex;
    flex: none;
    font-size: 0.875rem;
    height: 1.5rem;
    justify-content: space-between;
    padding-left: 1rem;
}
.news__header__text {
    line-height: 1rem;
}
.news__header__text__phone-icon {
    color: #53a1b3;
    display: none;
    height: 1rem;
    margin: 0 0.25rem;
    position: relative;
    top: 0.125rem;
    width: 1rem;
}
.news__header__text__dark-reader {
    font-weight: bold;
}
.news__header__text__mobile {
    color: #ffffff;
}
.news__close {
    color: #e96c4c;
    cursor: pointer;
    display: inline-block;
    font-size: 1.125rem;
    height: 1.5rem;
    line-height: 1.5rem;
    text-align: center;
    user-select: none;
    width: 1.5rem;
}
.news__close:hover {
    background-color: rgba(49, 110, 125, 0.25);
}
.news__list {
    background-color: rgba(20, 30, 36, 0.95);
    border-bottom: 0.125rem solid #316e7d;
    flex: auto;
    padding: 0.75rem 1rem;
    position: relative;
}
.news__list > :not(:first-child) {
    margin-top: 0.5rem;
}
.news__event {
    color: #53a1b3;
    display: block;
    flex: none;
    position: relative;
}
.news__event__date {
    display: block;
    font-size: 0.625rem;
}
.news__event__link {
    color: inherit;
    display: inline-block;
    text-decoration: none;
}
.news__event__link:hover {
    text-decoration: underline;
}
.news__event__icon {
    background-position: center;
    background-repeat: no-repeat;
    background-size: contain;
    display: inline-block;
    height: 2.5rem;
    left: 0;
    position: absolute;
    top: calc(50% - 2.5rem / 2);
    width: 2.5rem;
}
.news__event--has-icon {
    padding-left: 3rem;
}
.news__event--unread {
    font-weight: bold;
}
.news__event--unread:first-child {
    color: #e96c4c;
}
.news__event--important {
    color: #e96c4c;
}
.news__event--important.news__event--unread::before {
    background-color: #e96c4c;
    content: "";
    height: 100%;
    position: absolute;
    right: calc(100% + 0.75rem / 2);
    text-align: center;
    top: 0;
    width: 0.125rem;
}
.news__read-more {
    color: inherit;
    display: block;
    text-decoration: none;
}
.news__read-more:hover {
    text-decoration: underline;
}
.news__read-more--unread {
    font-weight: bold;
}
.news__mobile {
    align-items: center;
    display: flex;
    flex-direction: row;
    gap: 0.5rem;
    padding-bottom: 0.125rem;
}
.news__mobile__left {
    display: flex;
    flex: auto;
    flex-direction: column;
    gap: 0.5rem;
}
.news__mobile__right {
    display: flex;
    flex: none;
}
.news__mobile__learn-more-container {
    align-items: center;
    display: flex;
    flex-direction: row;
    gap: 0.5rem;
}
.news__mobile__logos {
    display: flex;
    flex-direction: row;
    flex: none;
    gap: 0.25rem;
}
.news__mobile__learn-more {
    color: #53a1b3;
    font-weight: bold;
    transition: color 250ms;
}
.news__mobile__learn-more:hover {
    color: #ffffff;
}
.news__qr-code {
    border-radius: 5%;
    display: inline-block;
    height: 5rem;
    width: 5rem;
}
.news__os-icon {
    display: inline-block;
    height: 1.25rem;
    width: 1.25rem;
}
.news-button {
    overflow: visible;
    position: relative;
}
.news-button--active {
    border-top: none;
    padding-top: 0.125rem;
    z-index: 2;
}
.news-button::after {
    background-color: #e96c4c;
    border-radius: 0.4375rem;
    color: #ffffff;
    content: attr(data-count);
    font-size: 0.625rem;
    line-height: 0.875rem;
    min-width: 0.875rem;
    position: absolute;
    right: -0.29166667rem;
    top: -0.29166667rem;
    z-index: 3;
}
.news-button__phone-icon {
    display: inline-block;
    height: 1rem;
    width: 1rem;
}
.news-button__wrapper {
    align-items: center;
    display: flex;
    flex-direction: row;
    justify-content: center;
}
.site-list-settings {
    align-items: stretch;
    display: flex;
    flex-direction: column;
    min-height: 0;
    width: 100%;
}
.site-list-settings__toggle {
    border-bottom: none;
    flex: none;
}
.site-list-settings__shortcut {
    flex: none;
    white-space: nowrap;
}
.site-list-settings__text-list {
    flex: initial;
}
.site-toggle {
    color: #53a1b3;
    white-space: normal;
}
.site-toggle--disabled {
    opacity: 0.5;
    pointer-events: none;
}
.site-toggle__mark svg {
    fill: currentColor;
    height: 0.75rem;
    vertical-align: bottom;
    width: 0.75rem;
}
.site-toggle--active {
    color: #ffffff;
}
body {
    align-items: stretch;
    box-sizing: content-box;
    display: flex;
    flex-direction: column;
    height: 30rem;
    margin: 0 auto;
    padding: 1rem;
    position: relative;
    width: 15rem;
}
.header {
    flex: none;
}
.tab-panel {
    flex: auto;
    margin-top: 0.75rem;
}
footer {
    align-items: stretch;
    display: flex;
    flex: none;
    flex-direction: column;
    justify-content: center;
    margin-top: 0.75rem;
}
footer p {
    margin: 0 0 0.125rem 0;
    text-align: center;
    white-space: pre;
}
.footer-links {
    align-items: stretch;
    display: flex;
    flex: none;
    justify-content: center;
    margin-bottom: 0.5rem;
}
.footer-links__link {
    color: #53a1b3;
    line-height: 1rem;
    text-align: center;
    text-decoration: none;
}
.footer-links__link:hover {
    text-decoration: underline;
}
.footer-links > :not(:first-child) {
    margin-left: 0.5rem;
}
.footer-buttons {
    align-items: stretch;
    display: flex;
    flex-direction: row;
    justify-content: stretch;
    width: 100%;
}
.footer-buttons > * {
    flex: auto;
}
.footer-buttons > :not(:first-child) {
    margin-left: 0.5rem;
}
.donate-link {
    align-items: center;
    background-color: #316e7d;
    color: #ffffff;
    cursor: pointer;
    display: inline-flex;
    height: 1.75rem;
    justify-content: center;
    margin: 0;
    position: relative;
    text-decoration: none;
    transition: all 125ms;
}
.donate-link:hover {
    box-shadow: 0 0 0.75rem #316e7d;
}
.donate-link__text {
    font-weight: bold;
    line-height: 0.75rem;
    text-align: center;
    transform: skewX(-10deg);
}
.dev-tools-button {
    overflow: visible;
    position: relative;
}
.ext-disabled .site-toggle--disabled {
    opacity: 1;
}
.ext-disabled .header__site-toggle,
.ext-disabled .tab-panel {
    opacity: 0.5;
    pointer-events: none;
}
.ext-disabled .tab-panel__tab--active {
    pointer-events: none;
}
.mobile-link {
    align-items: center;
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    border-bottom-left-radius: 1rem;
    border-top-left-radius: 1rem;
    box-sizing: border-box;
    cursor: pointer;
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    margin-top: 0.75rem;
    position: relative;
    text-decoration: none;
    user-select: none;
}
.mobile-link__icon {
    background-image: url("../assets/images/mobile-icon-40x64.svg");
    background-position: center;
    background-repeat: no-repeat;
    background-size: cover;
    border-radius: 0.4375rem;
    display: inline-block;
    flex: none;
    height: 2.8rem;
    left: -0.125rem;
    overflow: hidden;
    position: absolute;
    width: 1.75rem;
}
.mobile-link__text {
    color: #ffffff;
    flex: auto;
    font-weight: bold;
    height: 2rem;
    line-height: 1rem;
    margin: 0.125rem 1rem 0.125rem 2rem;
    text-align: center;
    overflow: hidden;
}
.mobile-link__text::after {
    content: " →";
    font-weight: bold;
}
.mobile-link:hover {
    background-color: #193945;
}
.mobile-link:hover .mobile-link__icon {
    box-shadow: 0 0 0.5rem #53a1b3;
}
.mobile-link:active {
    background-color: #316e7d;
}
.mobile-link {
    display: none;
}
.birthday-container {
    align-items: stretch;
    column-gap: 0.5rem;
    display: grid;
    grid: "icon message" auto "button button" 1.75rem / 2rem auto;
    width: 15rem;
}
.birthday-container .birthday-icon {
    background-image: url(../assets/images/birthday-icon.svg);
    background-position: center;
    background-repeat: no-repeat;
    background-size: contain;
    display: inline-block;
    grid-area: icon;
    height: 2rem;
    line-height: 2rem;
    margin: 0.5rem 0;
    text-align: center;
    text-indent: -999rem;
    width: 2rem;
}
.birthday-container .birthday-message {
    align-items: center;
    color: #ffffff;
    display: flex;
    flex-direction: column;
    grid-area: message;
    height: 3rem;
    line-height: 1rem;
    justify-content: center;
    text-align: left;
}
.birthday-container .birthday-message a {
    color: #ffffff;
}
.birthday-container .birthday-message-darkreader {
    color: #e96c4c;
    font-weight: bold;
    text-transform: uppercase;
    -webkit-text-stroke: 0.0625rem;
}
.birthday-container .donate-link {
    background-color: transparent;
    background-image: linear-gradient(
        to right,
        rgba(25, 57, 69, 0.5),
        #255461,
        rgba(25, 57, 69, 0.5)
    );
    box-shadow: none;
    box-sizing: border-box;
    grid-area: button;
    transition: all 250ms;
    width: 100%;
}
.birthday-container .donate-link:hover {
    background-color: #255461;
    box-shadow: none;
}
.m-birthday .birthday-icon {
    margin-top: 0;
}
.m-birthday .birthday-message {
    height: 2rem;
    margin-bottom: 0.5rem;
}
.ui-upgrade {
    align-items: stretch;
    column-gap: 0.5rem;
    cursor: pointer;
    display: grid;
    grid: "icon message" auto "button button" 1.75rem / 2rem auto;
    justify-content: center;
    line-height: 1;
    text-align: center;
    width: 15rem;
}
.ui-upgrade__icon {
    background-image: url(../assets/images/mode-dark-32.svg);
    background-position: center;
    background-repeat: no-repeat;
    background-size: contain;
    display: inline-block;
    grid-area: icon;
    height: 2rem;
    line-height: 2rem;
    margin: 0.5rem 0;
    text-align: center;
    text-indent: -999rem;
    width: 2rem;
}
.ui-upgrade__message {
    align-items: center;
    display: inline-flex;
    grid-area: message;
    justify-content: center;
    min-height: 2rem;
    text-align: left;
}
.ui-upgrade__button {
    background-image: linear-gradient(
        to right,
        #e96c4c,
        hsl(255, 23%, 56%),
        #53a1b3
    );
    color: white;
    display: inline-block;
    font-weight: bold;
    grid-area: button;
    padding: 0.125rem;
    position: relative;
}
.ui-upgrade__button__text {
    align-items: center;
    background-color: #141e24;
    display: inline-flex;
    height: calc(100% - 2 * 0.125rem);
    justify-content: center;
    left: 0.125rem;
    position: absolute;
    top: 0.125rem;
    transition: opacity 250ms;
    width: calc(100% - 2 * 0.125rem);
}
.ui-upgrade__button::before {
    background-color: white;
    content: "";
    height: 100%;
    left: 0;
    opacity: 0;
    position: absolute;
    top: 0;
    transition: opacity 250ms;
    width: 100%;
}
.ui-upgrade__button:hover::before {
    opacity: 1;
}
.ui-upgrade__button:hover .ui-upgrade__button__text {
    background-color: #193945;
}
.footer-help-link {
    align-items: center;
    background-color: #141e24;
    border: 0.125rem solid #316e7d;
    color: #ffffff;
    cursor: pointer;
    display: inline-flex;
    font-weight: bold;
    justify-content: center;
    margin: 0;
    position: relative;
    text-decoration: none;
    transition: all 125ms;
}
.footer-help-link::before {
    background-color: #316e7d;
    border-radius: 50%;
    box-sizing: border-box;
    color: #ffffff;
    content: "?";
    display: inline-block;
    font-weight: bold;
    height: 1rem;
    margin-right: 0.125rem;
    text-align: center;
    -webkit-text-stroke: 0.0625rem;
    width: 1rem;
}
.footer-help-link:hover {
    background-color: #193945;
}
body {
    border: 2px solid white;
}
html:not(.mobile):not(.preview) body.ext-tall {
    height: 34rem;
}
.overlay {
    height: calc(100% - 4px);
    left: 2px;
    top: 2px;
    width: calc(100% - 4px);
}
.mobile body {
    border: none;
    height: auto;
    position: relative;
}
.mobile .m-section,
.preview .m-section {
    width: 100%;
}
.mobile .m-section:not(:first-child),
.preview .m-section:not(:first-child) {
    margin-top: 0.75rem;
}
.mobile .m-section > :not(:first-child),
.preview .m-section > :not(:first-child) {
    margin-top: 0.5rem;
}
.mobile .pages-section,
.preview .pages-section {
    height: 24.4375rem;
}
.mobile .m-logo,
.preview .m-logo {
    background-image: url("../assets/images/darkreader-type.svg");
    background-position: center;
    background-size: 100%;
    display: inline-block;
    grid-area: logo;
    height: 1.5rem;
    margin: 0 auto;
    outline: none;
    text-indent: -999rem;
    width: 15rem;
}
.mobile .m-help-button,
.preview .m-help-button {
    align-items: center;
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M2,1 h1.5 l3,3 l-3,3 h-1.5 l3,-3 z"/></svg>');
    background-position: center right 0.25rem;
    background-repeat: no-repeat;
    background-size: 1rem;
    border: 0.125rem solid #316e7d;
    display: inline-flex;
    justify-content: center;
    height: 1.5rem;
    text-decoration: none;
    width: calc(100% - 2 * 0.125rem);
}
.mobile .m-help-button:hover,
.preview .m-help-button:hover {
    background-color: #193945;
    transition: background-color 125ms;
}
.mobile .m-help-button__text,
.preview .m-help-button__text {
    color: #ffffff;
    display: inline-block;
    line-height: 1.5rem;
    height: 1.5rem;
    -moz-user-select: none;
    user-select: none;
}
.mobile .m-help-button__text::before,
.preview .m-help-button__text::before {
    border: 0.0625rem solid #ffffff;
    border-radius: 50%;
    color: #ffffff;
    content: "?";
    display: inline-block;
    font-weight: bold;
    height: 0.875rem;
    left: 0;
    line-height: 0.875rem;
    margin-right: 0.25rem;
    text-align: center;
    top: 0;
    width: 0.875rem;
}
.mobile .m-donate-group,
.preview .m-donate-group {
    align-items: stretch;
    display: flex;
    flex-direction: column;
}
.mobile .m-donate-button,
.preview .m-donate-button {
    align-items: center;
    background-color: black;
    border: 0.125rem solid #316e7d;
    box-sizing: border-box;
    display: inline-flex;
    height: 1.75rem;
    isolation: isolate;
    justify-content: center;
    text-decoration: none;
    transition: 250ms background-color;
    position: relative;
    width: 100%;
}
.mobile .m-donate-button__text,
.preview .m-donate-button__text {
    color: #ffffff;
    display: inline-block;
    font-weight: bold;
    height: 1.5rem;
    line-height: 1.5rem;
    -moz-user-select: none;
    user-select: none;
}
.mobile .m-donate-button__darkreader,
.preview .m-donate-button__darkreader {
    color: #e96c4c;
    text-transform: uppercase;
    -webkit-text-stroke: 0.0625rem;
}
.mobile .m-donate-button__icon,
.preview .m-donate-button__icon {
    display: none;
    isolation: isolate;
}
.mobile .m-donate-button__icon::before,
.preview .m-donate-button__icon::before,
.mobile .m-donate-button__icon::after,
.preview .m-donate-button__icon::after {
    border-radius: 50%;
    content: "";
    display: inline-block;
    height: 1rem;
    mix-blend-mode: screen;
    position: absolute;
    top: 0.375rem;
    width: 1rem;
}
.mobile .m-donate-button__icon::before,
.preview .m-donate-button__icon::before {
    background-color: #e96c4c;
    left: 0.375rem;
}
.mobile .m-donate-button__icon::after,
.preview .m-donate-button__icon::after {
    background-color: #53a1b3;
    left: 1rem;
}
.mobile .m-donate-button:hover,
.preview .m-donate-button:hover {
    background-color: #141e24;
}
.mobile .m-donate-description,
.preview .m-donate-description,
.mobile .darkreader-version,
.preview .darkreader-version {
    display: inline-block;
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
    -moz-user-select: none;
    user-select: none;
    width: 100%;
}
.mobile .darkreader-version,
.preview .darkreader-version {
    bottom: 0;
    margin-bottom: 0.125rem;
    position: absolute;
    right: 0;
}
.mobile .darkreader-version {
    position: relative;
}
.preview .dev-tools-button {
    overflow: visible;
    position: relative;
    width: calc(100% - 2 * 0.125rem);
}
.mobile .app-switch__control,
.preview .app-switch__control {
    width: calc(100% - 0.125rem * 2);
}
.mobile .app-switch__description--on,
.preview .app-switch__description--on {
    color: #3bc077;
}
.mobile .app-switch__description--off,
.preview .app-switch__description--off {
    color: #e96c4c;
}
.mobile .app-switch__time,
.preview .app-switch__time {
    background-color: #e96c4c;
    border-radius: 50%;
    color: #ffffff;
    cursor: pointer;
    display: none;
    height: 0.875rem;
    pointer-events: none;
    position: absolute;
    right: calc(33% + 0.125rem / 3);
    top: -0.21875rem;
    transition: opacity 250ms 250ms;
    width: 0.875rem;
}
.mobile .app-switch__time--active,
.preview .app-switch__time--active {
    display: inline-block;
}
.mobile .settings-button-icon,
.preview .settings-button-icon {
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 16 16"><defs><path id="cog" d="M-1.25,-6.5 h2.5 l1,3 h-4.5 z" /></defs><g transform="translate(8 8)" fill="white"><path d="M0,-5 a5,5 0 0 1 0,10 a5,5 0 0 1 0,-10 z M0,-3 a3,3 0 0 0 0,6 a3,3 0 0 0 0,-6 z"></path><use xlink:href="%23cog" /><use xlink:href="%23cog" transform="rotate(60)" /><use xlink:href="%23cog" transform="rotate(120)" /><use xlink:href="%23cog" transform="rotate(180)" /><use xlink:href="%23cog" transform="rotate(240)" /><use xlink:href="%23cog" transform="rotate(300)" /></g></svg>');
    background-size: cover;
    display: inline-block;
    height: 1rem;
    margin-right: 0.125rem;
    width: 1rem;
}
.mobile .site-toggle-group .site-toggle,
.preview .site-toggle-group .site-toggle {
    width: calc(100% - 0.125rem * 2);
}
.mobile .site-toggle-group__description--on,
.preview .site-toggle-group__description--on {
    color: #3bc077;
}
.mobile .site-toggle-group__description--off,
.preview .site-toggle-group__description--off {
    color: #e96c4c;
}
.mobile .theme-group,
.preview .theme-group {
    align-items: stretch;
    display: flex;
    flex-direction: column;
}
.mobile .theme-group__presets-wrapper,
.preview .theme-group__presets-wrapper {
    background-color: #316e7d;
    border: 0.125rem solid #316e7d;
    height: 1.5rem;
    position: relative;
}
.mobile .theme-group__presets-wrapper::before,
.preview .theme-group__presets-wrapper::before {
    border: 0.125rem solid #316e7d;
    border-bottom: none;
    content: "";
    display: inline-block;
    height: 1.75rem;
    left: -0.125rem;
    position: absolute;
    top: -0.125rem;
    width: 100%;
}
.mobile .theme-group__controls-wrapper,
.preview .theme-group__controls-wrapper {
    border-bottom: 0.125rem solid #316e7d;
    border-left: 0.125rem solid #316e7d;
    border-right: 0.125rem solid #316e7d;
    padding: 0.5rem;
}
.mobile .theme-group__more-button,
.preview .theme-group__more-button {
    background-color: #316e7d;
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M2,1 h1.5 l3,3 l-3,3 h-1.5 l3,-3 z"/></svg>');
    background-position: center right 0.25rem;
    background-repeat: no-repeat;
    background-size: 1rem;
    border: none;
    height: 1.25rem;
    margin-bottom: 0.125rem;
    margin-top: 0.625rem;
    width: 100%;
}
.mobile .theme-group__description,
.preview .theme-group__description {
    display: inline-block;
    font-size: 0.625rem;
    line-height: 0.875rem;
    text-align: center;
    -moz-user-select: none;
    user-select: none;
    width: 100%;
}
.mobile .news-section,
.preview .news-section {
    background-color: #141e24;
    border-bottom-left-radius: 0.9375rem;
    border-bottom-right-radius: 0.9375rem;
    bottom: 0;
    box-sizing: border-box;
    display: flex;
    flex-direction: column;
    height: 1.875rem;
    left: 0;
    overflow: hidden;
    padding: 0;
    position: absolute;
    text-align: center;
    transition: height 250ms;
    user-select: none;
    white-space: nowrap;
    width: 100%;
}
.mobile .news-section__popover,
.preview .news-section__popover {
    align-items: stretch;
    background-color: #141e24;
    display: flex;
    flex-direction: column;
    left: 0;
    height: 6rem;
    opacity: 0;
    pointer-events: none;
    position: absolute;
    top: 0;
    transition: opacity 250ms;
    width: 100%;
}
.mobile .news-section__popover__top,
.preview .news-section__popover__top {
    border-top: 0.125rem solid #316e7d;
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    margin-bottom: 0.5rem;
}
.mobile .news-section__title,
.preview .news-section__title {
    color: #e96c4c;
    font-size: 0.875rem;
    line-height: 1.5rem;
    margin-left: 1rem;
}
.mobile .news-section__news,
.preview .news-section__news {
    align-items: center;
    box-sizing: border-box;
    color: #53a1b3;
    display: flex;
    flex-direction: row;
    font-weight: normal;
    justify-content: flex-start;
    height: 2.5rem;
    padding: 0 1rem;
    width: 100%;
}
.mobile .news-section__news__icon,
.preview .news-section__news__icon {
    background-position: center;
    background-repeat: no-repeat;
    background-size: contain;
    display: inline-block;
    flex: none;
    height: 3rem;
    margin-right: 0.5rem;
    width: 3rem;
}
.mobile .news-section__news__text,
.preview .news-section__news__text {
    flex: auto;
    font-size: 0.875rem;
    display: inline-block;
    line-height: 0.875rem;
    text-align: left;
    white-space: normal;
}
.mobile .news-section__news--highlight,
.preview .news-section__news--highlight {
    color: #e96c4c;
    font-weight: bold;
}
.mobile .news-section__news:hover,
.preview .news-section__news:hover {
    color: #ffffff;
}
.mobile .news-section__close,
.preview .news-section__close {
    color: #e96c4c;
    cursor: pointer;
    display: inline-block;
    font-size: 1.125rem;
    height: 1.5rem;
    line-height: 1.5rem;
    text-align: center;
    user-select: none;
    width: 1.5rem;
}
.mobile .news-section__close:hover,
.preview .news-section__close:hover {
    background-color: rgba(49, 110, 125, 0.25);
}
.mobile .news-section--expanded,
.preview .news-section--expanded {
    height: 6rem;
}
.mobile .news-section--expanded .news-section__popover,
.preview .news-section--expanded .news-section__popover {
    opacity: 1;
    pointer-events: all;
}
.mobile .news-section__news--small,
.preview .news-section__news--small {
    bottom: 0;
    font-weight: bold;
    height: 1.875rem;
    padding: 0 1rem;
}
.mobile .news-section__news--small .news-section__news__icon,
.preview .news-section__news--small .news-section__news__icon {
    height: 1.5rem;
    margin-right: 0.25rem;
    width: 1.5rem;
}
.mobile .news-section__news--small .news-section__news__text,
.preview .news-section__news--small .news-section__news__text {
    font-size: 0.75rem;
    line-height: 1rem;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}
.mobile .page-viewer,
.preview .page-viewer {
    height: 100%;
    position: relative;
}
.mobile .page,
.preview .page {
    align-items: stretch;
    background-color: #141e24;
    display: none;
    flex-direction: column;
    height: 100%;
    justify-content: stretch;
    left: 0;
    position: absolute;
    top: 0;
    width: 100%;
}
.mobile .page--active,
.preview .page--active {
    display: flex;
}
.mobile .page__back-button,
.preview .page__back-button {
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M6,1 h-1.5 l-3,3 l3,3 h1.5 l-3,-3 z"/></svg>');
    background-position: center left 0.25rem;
    background-repeat: no-repeat;
    background-size: 1rem;
    flex: none;
    margin-top: 0.5rem;
    width: calc(100% - 2 * 0.125rem);
}
.mobile .theme-control,
.preview .theme-control {
    align-items: center;
    display: flex;
    flex-direction: row;
    justify-content: center;
    min-height: 1.5rem;
    width: 100%;
}
.mobile .theme-control__label,
.preview .theme-control__label {
    font-size: 0.75rem;
    line-height: 0.75rem;
    text-align: left;
    -moz-user-select: none;
    user-select: none;
    width: 50%;
}
.mobile .export-theme-button,
.preview .export-theme-button {
    background-color: #316e7d;
    border: none;
    height: 1.25rem;
    margin-bottom: 0.25rem;
    margin-top: 0.625rem;
    width: 100%;
}
.mobile .static-edit-button,
.preview .static-edit-button {
    background-color: #e96c4c;
    border-radius: 0.4375rem;
    color: #ffffff;
    cursor: pointer;
    font-size: 0.625rem;
    line-height: 0.875rem;
    left: 0.25rem;
    min-width: 0.875rem;
    position: absolute;
    text-align: center;
    top: 0.25rem;
}
.mobile .static-edit-button--hidden,
.preview .static-edit-button--hidden {
    display: none;
}
.mobile .static-edit-button::before,
.preview .static-edit-button::before {
    content: "\270E";
    line-height: 0.875rem;
}
.mobile .static-edit-button:hover,
.preview .static-edit-button:hover {
    box-shadow: 0 0 0.75rem #ffffff;
}
.mobile .mode-control-container,
.preview .mode-control-container {
    height: 1.5rem;
    position: relative;
    width: 100%;
}
.mobile .collapsible-panel__group__expand-button,
.preview .collapsible-panel__group__expand-button {
    align-items: center;
    background-color: #316e7d;
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M3,0 h2 v3 h3 v2 h-3 v3 h-2 v-3 h-3 v-2 h3 z"/></svg>');
    background-position: center left 0.375rem;
    background-repeat: no-repeat;
    background-size: 0.5rem;
    color: #ffffff;
    cursor: pointer;
    display: none;
    height: 1.25rem;
    justify-content: center;
    line-height: 1.25rem;
    text-align: center;
    width: 100%;
}
.mobile
    .collapsible-panel__group--collapsed
    .collapsible-panel__group__expand-button,
.preview
    .collapsible-panel__group--collapsed
    .collapsible-panel__group__expand-button {
    display: inline-flex;
}
.mobile .collapsible-panel__group--collapsed .collapsible-panel__group__content,
.preview
    .collapsible-panel__group--collapsed
    .collapsible-panel__group__content {
    display: none;
}
.mobile
    .collapsible-panel__group--collapse-top
    .collapsible-panel__group__expand-button,
.preview
    .collapsible-panel__group--collapse-top
    .collapsible-panel__group__expand-button {
    margin-bottom: 0.625rem;
    margin-top: 0.125rem;
}
.mobile
    .collapsible-panel__group--collapse-bottom
    .collapsible-panel__group__expand-button,
.preview
    .collapsible-panel__group--collapse-bottom
    .collapsible-panel__group__expand-button {
    margin-bottom: 0.125rem;
    margin-top: 0.625rem;
}
.mobile .theme-page .theme-preset-picker.dropdown,
.preview .theme-page .theme-preset-picker.dropdown {
    height: 1.75rem;
}
.mobile .theme-page .theme-preset-picker .dropdown__selected,
.preview .theme-page .theme-preset-picker .dropdown__selected {
    height: 1.75rem;
}
.mobile .theme-page .theme-preset-picker .dropdown__list,
.preview .theme-page .theme-preset-picker .dropdown__list {
    border: 0.125rem solid #316e7d;
    border-top: none;
    box-shadow: 0 0 0.25rem 0.0625rem black;
    box-sizing: border-box;
}
.mobile .theme-page .theme-preset-picker .dropdown__list__item,
.preview .theme-page .theme-preset-picker .dropdown__list__item {
    min-height: 1.75rem;
}
.mobile .theme-page .theme-control:not(:first-child),
.preview .theme-page .theme-control:not(:first-child) {
    margin-top: 0.5rem;
}
.mobile .theme-page .font-picker,
.preview .theme-page .font-picker {
    box-sizing: border-box;
    height: 1.5rem;
    padding-top: 0.125rem;
    position: relative;
    width: 100%;
}
.mobile .theme-page .font-picker--disabled,
.preview .theme-page .font-picker--disabled {
    opacity: 0.5;
    pointer-events: none;
}
.mobile .theme-page .font-picker .select__textbox,
.preview .theme-page .font-picker .select__textbox,
.mobile .theme-page .font-picker .select__expand,
.preview .theme-page .font-picker .select__expand,
.mobile .theme-page .font-picker .select__list,
.preview .theme-page .font-picker .select__list {
    border: none;
}
.mobile .theme-page .font-picker .select__line,
.preview .theme-page .font-picker .select__line {
    position: relative;
}
.mobile .theme-page .font-picker .select__textbox,
.preview .theme-page .font-picker .select__textbox {
    background-color: #316e7d;
    color: #ffffff;
    height: 1.25rem;
    line-height: 1.25rem;
    text-align: center;
    width: 100%;
}
.mobile .theme-page .font-picker .select__textbox:hover,
.preview .theme-page .font-picker .select__textbox:hover {
    background-color: #193945;
}
.mobile .theme-page .font-picker .select__textbox:focus,
.preview .theme-page .font-picker .select__textbox:focus {
    background-color: #193945;
    border: 0.125rem solid #316e7d;
    margin-top: -0.125rem;
}
.mobile .theme-page .font-picker .select__expand,
.preview .theme-page .font-picker .select__expand {
    background-color: #316e7d;
    height: 1.25rem;
    min-width: 1.5rem;
    position: absolute;
    right: 0;
    top: 0;
    width: 1.5rem;
}
.mobile .theme-page .font-picker .select__expand__icon,
.preview .theme-page .font-picker .select__expand__icon {
    background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"><path fill="white" d="M1,2 l3,3 l3,-3 v1.5 l-3,3 l-3,-3 z"/></svg>');
    background-position: center;
    background-repeat: no-repeat;
    background-size: 1rem;
}
.mobile .theme-page .font-picker .select__expand__icon::before,
.preview .theme-page .font-picker .select__expand__icon::before,
.mobile .theme-page .font-picker .select__expand__icon::after,
.preview .theme-page .font-picker .select__expand__icon::after {
    display: none;
}
.mobile .theme-page .font-picker .select__list,
.preview .theme-page .font-picker .select__list {
    border-left: 0.125rem solid #316e7d;
    border-right: 0.125rem solid #316e7d;
    top: 100%;
    width: 100%;
}
.mobile .theme-page .font-picker .select__list--expanded,
.preview .theme-page .font-picker .select__list--expanded {
    border-bottom: 0.125rem solid #316e7d;
}
.mobile .theme-page .font-picker .select__list::-webkit-scrollbar,
.preview .theme-page .font-picker .select__list::-webkit-scrollbar {
    background-color: transparent;
}
.mobile .theme-page .font-picker.select--expanded,
.preview .theme-page .font-picker.select--expanded {
    background-color: #316e7d;
    height: 1.5rem;
    padding-top: 0;
}
.mobile .theme-page .font-picker.select--expanded .select__textbox,
.preview .theme-page .font-picker.select--expanded .select__textbox {
    border: 0.125rem solid #316e7d;
}
.mobile .theme-page .font-picker.select--expanded .select__textbox:focus,
.preview .theme-page .font-picker.select--expanded .select__textbox:focus {
    margin-top: 0;
}
.mobile .theme-page .font-picker.select--expanded .select__expand,
.preview .theme-page .font-picker.select--expanded .select__expand {
    margin-top: 0.125rem;
}
.mobile .theme-page .font-picker.select--expanded::before,
.preview .theme-page .font-picker.select--expanded::before {
    background-color: #141e24;
    content: "";
    display: inline-block;
    height: 0.75rem;
    left: 0.125rem;
    position: absolute;
    top: 0.75rem;
    width: calc(100% - 2 * 0.125rem);
}
.mobile .theme-preset-picker .dropdown__selected,
.preview .theme-preset-picker .dropdown__selected {
    height: 1.5rem;
    margin-top: 0;
}
.mobile .theme-preset-picker .dropdown__list,
.preview .theme-preset-picker .dropdown__list {
    border: none;
    box-shadow:
        0 0 0 0.125rem #316e7d,
        0 0 0.25rem 0.1875rem black;
}
.mobile .theme-preset-picker__preset,
.preview .theme-preset-picker__preset {
    align-items: center;
    display: inline-flex;
    justify-content: center;
    min-height: 1.5rem;
    position: relative;
    width: 100%;
}
.mobile .theme-preset-picker__preset__remove-button,
.preview .theme-preset-picker__preset__remove-button {
    cursor: pointer;
    display: inline-block;
    height: 1.5rem;
    position: absolute;
    right: 0;
    top: 0;
    width: 1.5rem;
}
.mobile .theme-preset-picker__preset__remove-button::after,
.preview .theme-preset-picker__preset__remove-button::after {
    content: "\2715";
    display: inline-block;
    line-height: 1.5rem;
    text-align: center;
}
.mobile .theme-preset-picker__preset__remove-button:hover,
.preview .theme-preset-picker__preset__remove-button:hover {
    background-color: #316e7d;
    color: #ffffff;
}
.preview .m-body-short {
    height: 27.5rem;
}
.mobile.firefox * {
    font-family:
        Inter,
        Open Sans,
        Segoe UI,
        Helvetica Neue,
        Ubuntu,
        sans-serif;
}
.mobile.firefox a,
.mobile.firefox a *,
.mobile.firefox button,
.mobile.firefox button * {
    font-family:
        Metropolis,
        Open Sans,
        Segoe UI,
        Helvetica Neue,
        Ubuntu,
        sans-serif;
}
@media screen and (min-width: 21.25rem) {
    .mobile {
        font-size: 20px;
    }
}
@media screen and (min-width: 25.5rem) {
    .mobile {
        font-size: 24px;
    }
}
@media screen and (min-resolution: 29.75rem) {
    .mobile {
        font-size: 28px;
    }
}
@media screen and (min-width: 34rem) {
    .mobile {
        font-size: 32px;
    }
}
.firefox .darkreader-version {
    display: none;
}
.preview:not(.mobile) body {
    border-color: #8a8f92;
}
html:not(.mobile) {
    width: calc(15rem + 2 * 1rem + 4px);
}
